@@ -2,16 +2,16 @@
 #######################################################################
 """MixIn class for backreference viewlet.
 
-$Id: viewletbackref.py 51952 2008-10-23 20:14:11Z cray $
+$Id: viewletbackref.py 52240 2008-12-29 00:25:58Z cray $
 """
 __author__  = "Andrey Orlov,2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52240 $"
 
 from ng.site.content.search.interfaces import ISearch, ISearchName
 from zope.app import zapi 
 import zope.app.catalog.interfaces
-from ng.skin.base.page.contentlet.viewletbase import ViewletBase
+from ng.lib.viewletbase import ViewletBase
 
 class ViewletBackRef(ViewletBase) :
     """ Wiki """
