@@ -2,14 +2,14 @@
 #######################################################################
 """Mix-in class for document view viewlet
 
-$Id: body.py 51952 2008-10-23 20:14:11Z cray $
+$Id: body.py 52240 2008-12-29 00:25:58Z cray $
 """
 __author__  = "Andrey Orlov,2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52240 $"
 
 from ng.app.converter.object2psadapter.interfaces import IPropertySheet
-from ng.skin.base.page.contentlet.viewletbase import ViewletBase
+from ng.lib.viewletbase import ViewletBase
 
 class Proxy(object) :
     def __init__(self,ob) :
