@@ -2,14 +2,14 @@
 #######################################################################
 """MixIn class for inbody viewlet 
 
-$Id: inbody.py 51952 2008-10-23 20:14:11Z cray $
+$Id: inbody.py 52316 2009-01-13 11:53:09Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52316 $"
 
 from ng.app.converter.object2psadapter.interfaces import IPropertySheet
-from ng.skin.base.page.contentlet.viewletbase import ViewletBase
+from ng.lib.viewletbase import ViewletBase
 
 class InBody(ViewletBase) :
     """ Body """
