@@ -2,11 +2,11 @@
 #######################################################################
 """MixIn class for searchpage.
 
-$Id: searchpage.py 52411 2009-01-30 11:46:32Z cray $
+$Id: searchpage.py 52739 2009-03-28 14:11:44Z cray $
 """
 __author__  = "Andrey Orlov 2006 12 05"
 __license__ = "GPL"
-__version__ = "$Revision: 52411 $"
+__version__ = "$Revision: 52739 $"
 
 import zope.component
 from zope.app import zapi
@@ -77,17 +77,26 @@ class Search(object) :
         if 'email' in d and not d['email'] :
             del d['email']
         
+        crosswiki = None
+        if 'crosswiki' in d :
+            crosswiki = d['crosswiki']
+            del d['crosswiki']
+            
+
         res = zapi.getUtility(ICatalog,context=self.context).searchResults(**d)        
         pagersource = ResultSet2PagerSourceAdapter(res)
 
         if len(res) == 0 :
             if "keyword" in self.request.form :
-                url = \
-                  adaptiveURL(zapi.getUtility(
+                dictionary = zapi.getUtility(
                       zope.app.container.interfaces.IContainer,
-                      name="Main",context=self.context)['dictionary'],self.request)
-                if check(self.context,self.request) :
-                    self.request.response.redirect(url+"/+/AddDictionaryItem.html=?field.keyword.0.=%(keyword)s&field.keyword.count=1&field.title=%(keyword)s" % { 'keyword': self.quotenextkeyword } )
+                      name="Main",context=self.context)['dictionary']
+                if check(dictionary,self.request) :
+                    self.request.response.redirect(
+                      adaptiveURL(dictionary,self.request)
+                      +"/+/AddDictionaryItem.html=?field.keyword.0.=%(keyword)s&field.keyword.count=1&field.title=%(keyword)s&crosswiki=%(crosswiki)s" % { 'keyword': self.quotenextkeyword,  'crosswiki' : crosswiki } ) 
+                elif crosswiki :
+                    self.request.response.redirect("%(crosswiki)s/@@searchpage.html?query=%(keyword)s&predicate=keyword" % { 'keyword': self.quotenextkeyword, 'crosswiki' : crosswiki } )
             elif "name" in self.request.form :
                 url = adaptiveURL(self.context,self.request)
                 if check(self.context,self.request) :
