@@ -3,11 +3,11 @@
 """Base class for a few viewlet display different folderish content
 as menu.
 
-$Id: mainbox.py 52380 2009-01-18 15:45:16Z cray $
+$Id: mainbox.py 52841 2009-04-06 18:01:31Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 52380 $"
+__version__ = "$Revision: 52841 $"
 
 from zope.app.container.interfaces import IContainer
 from zope.app.zapi import getSiteManager
@@ -42,5 +42,3 @@ class MainBox(ViewletBase) :
         return getSiteManager(context=self.context) \
                 .getUtility(self.folderinterface, self.foldername)
                 
-    def __cmp__(self,ob) :
-        return cmp(self.order,ob.order)
